#![forbid(unsafe_code)]

use std::process::exit;
use log;

mod gitea;
mod api;

const TG_KEY: &str = dotenvy_macro::dotenv!("TG_KEY", "Telegram key is not set!");
const GITEA_KEY: &str = dotenvy_macro::dotenv!("GITEA_KEY", "Gitea key is not set!");
const GITEA_URL: &str = dotenvy_macro::dotenv!("GITEA_URL", "Gitea url is not set!");

#[tokio::main]
async fn main() {
    
    #[cfg(debug_assertions)]
    femme::with_level(log::LevelFilter::Debug);

    #[cfg(not(debug_assertions))] {
        femme::with_level(log::LevelFilter::Info);
        log::info!("Running in production");
    }

    let user = api::get_user().await;
    log::info!("Logged into gitea as user \"{}\"", user.full_name);

    let repos = api::get_org_repos("Tochka".into()).await;
    log::info!("Found {} repositories", repos.len());

    let repos = api::filter_repos(repos);
    log::info!("Only {} repositories are useful", repos.len());

    
}
